/***************************************************************************
 *  @file commands.h
 *
 *  @date   : 05-09-04
 *  @author : Pedro Ortega C. <peortega@dcc.uchile.cl>
 *  Copyright  2004  Pedro Ortega C.
 ****************************************************************************/
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _COMMANDS_H_
#define _COMMANDS_H_

/******************/
/* Include Files. */
/******************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>



/***************************/
/* Macros and Definitions. */
/***************************/

#define BW_MAX_FILES 64


/******************************/
/* Typedefs and declarations. */
/******************************/

typedef struct bwcommand bwcommand;
typedef int (*bwexectype)(int argc, char **argv);
typedef int (*bwhelptype)(FILE *fp);

struct bwcommand
{
    char *name;
    char *short_description;
    char *short_args_format;
    bwexectype exec;
    bwhelptype help;
};



/*********************/
/* Public interface. */
/*********************/

/* Commands. */

int convert(int argc, char **argv);
int select(int argc, char **argv);
int concat(int argc, char **argv);
int select_channel(int argc, char **argv);
int merge_channel(int argc, char **argv);
int display_info(int argc, char **argv);

/* Help functions. */

int convert_help(FILE *fp);
int select_help(FILE *fp);
int concat_help(FILE *fp);
int select_channel_help(FILE *fp);
int merge_channel_help(FILE *fp);
int display_info_help(FILE *fp);

/* Utility functions. */

size_t sec2pos(float sec);
float  pos2sec(size_t pos);

/* Command registration array. */

extern bwcommand commands[];




#endif /* _COMMANDS_H_ */

