/***************************************************************************
 *  @file display_info.c
 *
 *  @date   : 05-09-04
 *  @author : Pedro Ortega C. <peortega@dcc.uchile.cl>
 *  Copyright  2004  Pedro Ortega C.
 ****************************************************************************/
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/******************/
/* Include files. */
/******************/

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "file.h"
#include "commands.h"



/************************/
/* Static declarations. */
/************************/



/**************************/
/* Static implementation. */
/**************************/



/************************************/
/* Public interface implementation. */
/************************************/

int
display_info_help(FILE *fp)
{
    fprintf(fp, "\n");
    fprintf(fp, "Displays some useful info about the source file.\n");
    fprintf(fp, "\n");
    fprintf(fp, "Use: bwtool display-info <src>\n");
    fprintf(fp, "\n");

    return 0;
}

int
display_info(int argc, char **argv)
{
    bwfile *src;
    bwsample *in;

    // check arguments
    if (argc != 3)
    {
        display_info_help(stderr);
        return 1;
    }

    // open brainwave stream
    src  = bwopen(argv[2]);
    if (src == NULL)
    {
        fprintf(stderr, "Couldn't open \"%s\".\n", argv[2]);
        return 1;
    }

    // build sample structure
    in  = bwsample_new(src->nchan);

    // read
    while (bwread(src, in) != EOF)
        ;

    // print info
    printf("File     : %s\n", src->name);
    printf("Format   : %s\n", src->type);
    if (src->is_text)
        printf("Text     : yes\n");
    else
        printf("Text     : no\n");
    printf("Channels : %d\n", src->nchan);
    printf("Seconds  : %6.2f\n", pos2sec(src->pos - 1));
    printf("Samples  : %ld\n", src->pos-1);
    printf("S/Rate   : 256\n");

    // close
    bwclose(src);
    bwsample_destroy(in);

    return 0;
}



