/***************************************************************************
 *  @file file.h
 *
 *  @date   : 05-09-04
 *  @author : Pedro Ortega C. <peortega@dcc.uchile.cl>
 *  Copyright  2004  Pedro Ortega C.
 ****************************************************************************/
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _FILE_H_
#define _FILE_H_

/******************/
/* Include files. */
/******************/

#include <stdlib.h>
#include <stdio.h>


/********************************/
/* Macros and type definitions. */
/********************************/

#define BW_MAX_CHAN 256
#define BW_MODE_READ  0
#define BW_MODE_WRITE 1


/************************************/
/* Structures and type definitions. */
/************************************/

typedef struct bwsample bwsample;
typedef struct bwfile   bwfile;
typedef int (*bwread_type)(bwfile *f, bwsample *s);
typedef int (*bwwrite_type)(bwfile *f, bwsample *s);
typedef int (*bwsetup_type)(bwfile *f);
typedef int (*bwcreate_type)(bwfile *f, int nchan);

struct bwsample
{
    long n;
    int  nchan;
    int *chan;
    int  err;
};

struct bwfile
{
    FILE *fp;
    char        *name;
    char        *type;
    int          is_text;
    size_t       pos;
    int          counter;
    int          nchan;
    bwread_type   read;
    bwwrite_type  write;
    bwsetup_type  setup;
    bwcreate_type create;
};



/*********************/
/* Public interface. */
/*********************/

bwfile* bwopen(const char *name);
bwfile* bwcreate(const char *name, int nchan);
int bwclose(bwfile *f);
int bwread(bwfile *f, bwsample *s);
int bwwrite(bwfile *f, bwsample *s);

bwsample *bwsample_new(int nchan);
int bwsample_destroy(bwsample *s);
int bwsample_resize(bwsample *s, int nchan);



#endif /* _FILE_H_ */


